OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "您为您的账号启用了 TOTP 两步验证",
    "You disabled TOTP two-factor authentication for your account" : "您为您的账号禁用了 TOTP 两步验证",
    "TOTP (Authenticator app)" : "TOTP (认证应用)",
    "Authenticate with a TOTP app" : "使用 TOTP 应用验证身份",
    "Two-Factor TOTP Provider" : "两步验证TOTP提供者",
    "Could not enable TOTP" : "无法启用 TOTP",
    "Could not verify your key. Please try again" : "无法验证您的密钥。请再次尝试",
    "Enable TOTP" : "启用 TOTP",
    "Your new TOTP secret is:" : "您的新 TOTP 密钥：",
    "For quick setup, scan this QR code with your TOTP app:" : "使用您的 TOTP 应用扫描二维码以快速安装：",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "在您配置好您的应用后，输入以下测试码来确保您的应用配置正确：",
    "Authentication code" : "验证码",
    "Verify" : "验证",
    "Get the authentication code from the two-factor authentication app on your device." : "从您设备上的两步验证应用获取验证码",
    "Submit" : "提交"
},
"nplurals=1; plural=0;");
